#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 glirc
version:              2.41
visibility:           public
id:                   glirc-2.41-FZs2CysAshLYturSkmRNK
key:                  glirc-2.41-FZs2CysAshLYturSkmRNK
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  840e8ad2e446b654e281f1c0b57bbcef
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Docs Client.Commands.Exec Client.Commands.Help
    Client.Commands.Interpolation Client.Commands.Operator
    Client.Commands.Queries Client.Commands.Recognizer
    Client.Commands.TabCompletion Client.Commands.Toggles
    Client.Commands.Types Client.Commands.Window
    Client.Commands.WordCompletion Client.Commands.ZNC
    Client.Configuration Client.Configuration.Colors
    Client.Configuration.Macros Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.Docs Client.EventLoop Client.EventLoop.Actions
    Client.EventLoop.Errors Client.EventLoop.Network Client.Hook
    Client.Hook.DroneBLRelay Client.Hook.Matterbridge
    Client.Hook.Snotice Client.Hook.Znc.Buffextras Client.Hooks
    Client.Image Client.Image.Focus Client.Image.Layout
    Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Help Client.State.Network
    Client.State.Target Client.State.Url Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.IgnoreList Client.View.KeyMap
    Client.View.MaskList Client.View.Mentions Client.View.Messages
    Client.View.Palette Client.View.RtsStats Client.View.UrlSelection
    Client.View.UserList Client.View.Who Client.View.WindowSwitch
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/glirc-2.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.41-FZs2CysAshLYturSkmRNK
include-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.10-6hHqFSiOfZ6Fry6FGRDGrR
    async-2.2.6-FyNZXdji95t98VleCj3HXu
    attoparsec-0.14.4-5xxMJ7hMTSZEwvbcpfcCWS base-4.18.2.1
    base64-bytestring-1.2.1.0-JBjEAAOdpBm2IYrolgjJx9
    bytestring-0.11.5.3 config-schema-1.3.0.0-AnPAMrVONZYKTPFDpxJuWV
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    curve25519-0.2.8.1-IBv9PRJ2qTM4ijuEQXcCyZ directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-43eMsTKpQ57AjddNsQFc3x
    githash-0.1.7.0-CqiS2eIPwZtFIV9ajnsAMI
    hashable-1.4.7.0-Eia1GH7GKUH7V9HVPMehAJ
    hookup-0.8-E6mHbCzYbUqUkNSlNWnVe
    irc-core-2.13-IUFmFpZ9jduATb7TNpOZDA
    kan-extensions-5.2.8-112G6Z6CXsD5yeWeEc4n80
    lens-5.3.5-FTj0s0XQNe34VtbjGE3NFc
    network-3.1.4.0-8HZ2mHT7KyE1ZVQfwLbJCE
    psqueues-0.2.8.3-tzu8qgJ3dk3QBh91Yr4Fw
    random-1.2.1.3-GfiOoTkiJ8dHrTrBUL8yXz
    regex-tdfa-1.3.2.6-G1rwxCg3bOv6wSXzJT4zAX
    semigroupoids-6.0.2-EM42hf7QGx74z9TdpT30mc
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 typed-process-0.2.13.0-9gzOG6vPMRhHnK7cOuD3Bl
    unix-2.8.4.0 unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk
    vty-6.2-HcTAeSrP5HH4j8ARXNvRz6

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

